import numpy as np

def linear_to_srgb(color):
    limit = 0.0031308
    color = np.where(color > limit, 1.055 * (color ** (1.0 / 2.4)) - 0.055, 12.92 * color)
    return color

def generate_color_sequence(num_colors):
    current_color = np.array([255.0, 255.0, 255.0])
        
    _r = np.arange(0, 256)
    colors = np.stack(np.meshgrid(_r, _r, _r, indexing='ij'), axis=-1).reshape(-1, 3)

    color_sequence = np.empty([0, 3])
    closest_color_distances = np.ones([colors.shape[0]]) * 100000000

    for i in range(num_colors):
        color_sequence = np.concatenate((color_sequence, current_color[None]), axis=0)
        closest_color_distances = np.minimum(closest_color_distances, ((colors - current_color)**2).sum(axis=-1))
        current_color = colors[closest_color_distances.argmax(axis=0)]
    
    return np.round(linear_to_srgb(color_sequence/255.0)*255.0).astype(np.uint8)

sequence = generate_color_sequence(100)

from PIL import Image
image = Image.fromarray(sequence.reshape(10, 10, 3)).save("output.png")